% This function returns the Parameter Estimates of the Job Ladder Model

function par = par_est(d)

    %% MAXIMUM LIKELIHOOD ESTIMATION

    % solver options
    options.MaxFunEvals = 100000;
    options.MaxIter     = 100000;

    % initial guesses for (delta,lambda0,lambda1)
    del0_i          = 0.05;
    del1_i          = 0.00;
    del2_i          = 0.00;
    del3_i          = 0.00;
    del4_i          = 0.00;
    lam00_i         = 0.15;
    lam01_i         = 0.0;
    lam02_i         = 0.0;
    lam03_i         = 0.0;
    lam04_i         = 0.0;
    lam10_i         = 0.03;
    lam11_i         = 0.0;
    lam12_i         = 0.0;
    lam13_i         = 0.0;
    lam14_i         = 0.0;

    % estimate the model from arbitrary starting point
    x0 = [del0_i; del1_i; del2_i; del3_i; del4_i; lam00_i; lam01_i; lam02_i; lam03_i; lam04_i; lam10_i; lam11_i; lam12_i; lam13_i; lam14_i];    

    xhat = fminunc(@(x)BMlikelihood_ATE(x,d,'scalar'),x0,options);

    %% STANDARD ERRORS

    % calculate the score
    score           = zeros(length(d.e),length(xhat));    % this just allocates memory
    dx              = .001;

    for j = 1:length(xhat);
       xprime       = xhat;
       xprime(j)    = xhat(j)+dx;
       score(:,j)   = ( BMlikelihood_ATE(xprime,d,'vect') - BMlikelihood_ATE(xhat,d,'vect') )/dx;
    end

    % information matrix
    info            = score'*score;

    % covariance matrix of parameter
    covmat          = inv(info);

    % calculate paramters and standard errors for treatment groups
    xhat_tr   = xhat;
    stderr_tr = sqrt(diag(covmat));
    for i=2:5;
        xhat_tr(i,1)   = xhat_tr(i,1)+xhat_tr(1,1);
        stderr_tr(i,1) = sqrt(covmat(i,i)+covmat(1,1)+covmat(1,i));

        xhat_tr(i+5,1)   = xhat_tr(i+5)+xhat_tr(6,1);
        stderr_tr(i+5,1) = sqrt(covmat(i+5,i+5)+covmat(6,6)+covmat(6,i+5));

        xhat_tr(i+10,1)   = xhat_tr(i+10)+xhat_tr(11,1);    
        stderr_tr(i+10,1) = sqrt(covmat(i+10,i+10)+covmat(11,11)+covmat(11,i+10));
    end
    
    % calculate p-values from t-test of significance
    pval = 1-tcdf(xhat./stderr_tr,d.n-16);
    
    % calculate p-values from F-test of joint significance of non-compliers
    R = zeros(2,5);
    R(1,2) = 1;
    R(2,4) = 1;
    
    nj=2; %number of hypothesis tested
    
    F=zeros(1,3);
    F(1,1)=1/nj*(R*xhat(1:5))'*inv((R*covmat(1:5,1:5)*R'))*(R*xhat(1:5));
    F(1,2)=1/nj*(R*xhat(6:10))'*inv((R*covmat(6:10,6:10)*R'))*(R*xhat(6:10));
    F(1,3)=1/nj*(R*xhat(11:15))'*inv((R*covmat(11:15,11:15)*R'))*(R*xhat(11:15));

    pvaljoint = zeros(1,3);
    pvaljoint(1,1) = 1-fcdf(F(1,1),nj,d.n-15);
    pvaljoint(1,2) = 1-fcdf(F(1,2),nj,d.n-15);
    pvaljoint(1,3) = 1-fcdf(F(1,3),nj,d.n-15);   
    
    % calculate standard error of VT compliers-FT compliers
    xdiff=zeros(3,2);
    xdiff(1,1)=xhat(3)-xhat(5); %difference
    xdiff(2,1)=xhat(8)-xhat(10);
    xdiff(3,1)=xhat(13)-xhat(15);
    xdiff(1,2)=sqrt(covmat(3,3)+covmat(5,5)-2*covmat(3,5)); %stderr
    xdiff(2,2)=sqrt(covmat(8,8)+covmat(10,10)-2*covmat(8,10));
    xdiff(3,2)=sqrt(covmat(13,13)+covmat(15,15)-2*covmat(13,15));
    
    % calculate p-values of differences
    pvaldiff=ones(3,1)-tcdf(abs(xdiff(:,1)./xdiff(:,2)),d.n-16);

    %% UNITS OF EFFECTIVE LABOUR

    % Generate matrices of eps for each treatment 
    re         = d.eps(d.eps>0);
    re_control = d.eps(d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.eps>0);
    re_vt_nc   = d.eps(d.treat_vt_nc==1&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.eps>0);
    re_vt_yc   = d.eps(d.treat_vt_nc==0&d.treat_vt_yc==1&d.treat_ft_nc==0&d.treat_ft_yc==0&d.eps>0);
    re_ft_nc   = d.eps(d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==1&d.treat_ft_yc==0&d.eps>0);
    re_ft_yc   = d.eps(d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==1&d.eps>0);

    %mean and standard deviation of productivity
    h_mean=ones(5,1);
    h_mean(1,1)=mean(re_control);
    h_mean(2,1)=mean(re_vt_nc);
    h_mean(3,1)=mean(re_vt_yc);
    h_mean(4,1)=mean(re_ft_nc);
    h_mean(5,1)=mean(re_ft_yc);

    %% OUTPUT

    %Display parameter estimates and standard errors
    par_t = ones(5,10);
    par_t(:,1) = h_mean;
    par_t(:,2) = xhat_tr(1:5,1);
    par_t(:,3) = stderr_tr(1:5,1);
    par_t(:,4) = xhat_tr(6:10,1);
    par_t(:,5) = stderr_tr(6:10,1);
    par_t(:,6) = xhat_tr(11:15,1);
    par_t(:,7) = stderr_tr(11:15,1);

    %Add other parameters needed for the remaining estimation
    par_t(:,8)  = xhat(1:5);
    par_t(:,9)  = xhat(6:10);
    par_t(:,10) = xhat(11:15);

    %Order the parameters as displayed in the table
    par(1,:) = par_t(1,:);
    par(2,:) = par_t(4,:);
    par(3,:) = par_t(2,:);
    par(4,:) = par_t(5,:);
    par(5,:) = par_t(3,:);

end