% This function returns the Parameter Estimates of the Job Ladder Model

function par = par_est(d)

    % solver options
    options.MaxFunEvals = 100000;
    options.MaxIter     = 100000;

    % initial guesses for (delta,lambda0,lambda1)
    del0_i          = 0.05;
    del1_i          = 0.00;
    del2_i          = 0.00;
    lam00_i         = 0.15;
    lam01_i         = 0.0;
    lam02_i         = 0.0;
    lam10_i         = 0.03;
    lam11_i         = 0.0;
    lam12_i         = 0.0;

    % initial guesses for (delta,lambda0,lambda1)
    x0 = [del0_i; del1_i; del2_i; lam00_i; lam01_i; lam02_i; lam10_i; lam11_i; lam12_i;];    

    % estimate the model from arbitrary starting point
    xhat = fminunc(@(x)BMlikelihood_ITT(x,d,'scalar'),x0,options);

    %% STANDARD ERRORS and CONFIDENCE INTERVALS
    
    % calculate the score
    score           = zeros(length(d.e),length(xhat));    % this just allocates memory
    dx              = .001;

    for j = 1:length(xhat);
       xprime       = xhat;
       xprime(j)    = xhat(j)+dx;
       score(:,j)   = ( BMlikelihood_ITT(xprime,d,'vect') - BMlikelihood_ITT(xhat,d,'vect') )/dx;
    end

    % information matrix
    info            = score'*score;

    % covariance matrix of sqrt(parameter)
    covmat          = inv(info);

    % calculate paramters and standard errors for treatment groups
    xhat_tr   = xhat;
    stderr_tr = sqrt(diag(covmat));
    for i=2:3;
        xhat_tr(i,1)   = xhat_tr(i,1)+xhat_tr(1,1);
        stderr_tr(i,1) = sqrt(covmat(i,i)+covmat(1,1)+covmat(1,i));

        xhat_tr(i+3,1)   = xhat_tr(i+3)+xhat_tr(4,1);
        stderr_tr(i+3,1) = sqrt(covmat(i+3,i+3)+covmat(4,4)+covmat(4,i+3));

        xhat_tr(i+6,1)   = xhat_tr(i+6)+xhat_tr(7,1);    
        stderr_tr(i+6,1) = sqrt(covmat(i+6,i+6)+covmat(7,7)+covmat(7,i+6));
    end

    % calculate standard error of VT compliers-FT compliers
    xdiff=zeros(3,2);
    xdiff(1,1)=xhat(3)-xhat(2); %difference
    xdiff(2,1)=xhat(6)-xhat(5);
    xdiff(3,1)=xhat(9)-xhat(8);
    xdiff(1,2)=sqrt(covmat(2,2)+covmat(3,3)-2*covmat(2,3)); %stderr
    xdiff(2,2)=sqrt(covmat(5,5)+covmat(6,6)-2*covmat(5,6));
    xdiff(3,2)=sqrt(covmat(8,8)+covmat(9,9)-2*covmat(8,9));
    
    % calculate p-values of differences
    pvaldiff=ones(3,1)-tcdf(abs(xdiff(:,1)./xdiff(:,2)),d.n-length(xhat)-1);
    
    
    %% UNITS OF EFFECTIVE LABOUR
    
    % create matrices of eps for each treatment 
    re         = d.eps(d.eps>0);
    re_control = d.eps(d.treat_vt==0&d.treat_ft==0&d.eps>0);
    re_vt      = d.eps(d.treat_vt==1&d.treat_ft==0&d.eps>0);
    re_ft      = d.eps(d.treat_vt==0&d.treat_ft==1&d.eps>0);

    % mean and standard deviation of productivity
    h_mean=ones(3,1);
    h_mean(1,1)=mean(re_control);
    h_mean(2,1)=mean(re_vt);
    h_mean(3,1)=mean(re_ft);
    
    % p-value from t-test of difference in means
    [h,p] = ttest2(re_vt,re_ft);

    %% OUTPUT

    %Display parameter estimates and standard errors
    par_t = ones(3,10);
    par_t(:,1) = h_mean;
    par_t(:,2) = xhat_tr(1:3,1);
    par_t(:,3) = stderr_tr(1:3,1);
    par_t(:,4) = xhat_tr(4:6,1);
    par_t(:,5) = stderr_tr(4:6,1);
    par_t(:,6) = xhat_tr(7:9,1);
    par_t(:,7) = stderr_tr(7:9,1);

    %Add other parameters needed for the remaining estimation
    par_t(:,8)  = xhat(1:3);
    par_t(:,9)  = xhat(4:6);
    par_t(:,10) = xhat(7:9);

    %Order the parameters as displayed in the table
    par(1,:) = par_t(1,:);
    par(2,:) = par_t(3,:);
    par(3,:) = par_t(2,:);

end